
import unittest2 as unittest

#from zope.component import queryUtility

from Products.CMFCore.utils import getToolByName

from plone.registry.interfaces import IRegistry
from plone.app.testing import TEST_USER_ID
from plone.app.testing import setRoles

from on.caroufredsel.testing import ON_CAROUFREDSEL_INTEGRATION_TESTING


class TestLibInRegistry(unittest.TestCase):
    """Test the integration of the product."""

    layer = ON_CAROUFREDSEL_INTEGRATION_TESTING

    def setUp(self):
        self.portal = self.layer['portal']
        setRoles(self.portal, TEST_USER_ID, ['Manager'])

    def test_can_we_find_the_library(self):
        """Get the registry and see whether we have this lib listed."""
        tool = getToolByName(self.portal, "portal_javascripts")
        self.assertNotEqual(tool, None)
        installedScriptIds = tool.getResourceIds()
        #import pdb; pdb.set_trace()
        self.assertTrue("++resource++on.caroufredsel.js" in installedScriptIds, "on.caroufredsel.js")
        self.assertTrue("++resource++on.caroufredsel-compact.js" in installedScriptIds, "on.caroufredsel-compact.js")



# (c) 2012 oeko.net
# c/o toni mueller <support@oeko.net>
# license: GPLv3

import unittest2 as unittest

from plone.app.testing import PloneSandboxLayer
from plone.app.testing import quickInstallProduct
from plone.app.testing import PLONE_FIXTURE
from plone.app.testing import IntegrationTesting
from plone.app.testing import FunctionalTesting

import Products.CMFPlone

from plone.app.testing import TEST_USER_ID
from plone.app.testing import TEST_USER_NAME
from plone.app.testing import TEST_USER_PASSWORD
from plone.app.testing import SITE_OWNER_NAME, SITE_OWNER_PASSWORD

#from plone.app.testing import setRoles

from plone.app.testing import applyProfile

from plone.testing import z2
from plone.registry.interfaces import IRegistry
from Products.CMFCore.utils import getToolByName

class OnCarouFredSelFixture(PloneSandboxLayer):
    defaultBases = (PLONE_FIXTURE,)

    def setUpZope(self, app, configurationContext):
        import on.caroufredsel
        self.loadZCML(package=on.caroufredsel)
        self.loadZCML(package=Products.CMFPlone)

    def setUpPloneSite(self, portal):
        wftool = getToolByName(portal, 'portal_workflow')
        wftool.setDefaultChain('folder_workflow')
        """Run the GS profile for this product"""
        self.applyProfile(portal, 'on.caroufredsel:default')
        #import pdb; pdb.set_trace()


    def tearDownZope(self, app):
        """Uninstall the product and destroy the Zope site"""
        z2.uninstallProduct(app, 'on.caroufredsel')

#    def manager_browser(self):
#        """Browser of Manager - not accessible from test layer
#        """
#        return self._auth_browser(SITE_OWNER_NAME, SITE_OWNER_PASSWORD)


ON_CAROUFREDSEL_FIXTURE = OnCarouFredSelFixture()
ON_CAROUFREDSEL_INTEGRATION_TESTING = IntegrationTesting(bases=(ON_CAROUFREDSEL_FIXTURE,), name="OnCarouFredSelFixture:Integration")
ON_CAROUFREDSEL_FUNCTIONAL_TESTING = FunctionalTesting(bases=(ON_CAROUFREDSEL_FIXTURE,), name="OnCarouFredSelFixture:Functional")




from setuptools import setup, find_packages
import os

version_file = os.path.join('on', 'caroufredsel', 'version.txt')
version = open(version_file).read().strip()

setup(name='on.caroufredsel',
      version=version,
      description="Shim to load Caroufredsel as a resource",
      long_description=open("README.rst").read() + "\n" +
                       open("CHANGES.rst").read(),
      # Get more strings from
      # http://pypi.python.org/pypi?:action=list_classifiers
      classifiers=[
        "Framework :: Plone",
	"Framework :: Plone :: 4.2",
	"Framework :: Plone :: 4.3",
        "Programming Language :: Python",
        "Programming Language :: JavaScript",
        ],
      keywords='Caroufredsel',
      author='Toni Mueller',
      author_email='support@oeko.net',
      url='https://github.com/muellert/on.caroufredsel.git',
      license='MIT + GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['on'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          # -*- Extra requirements: -*-
      ],
      entry_points="""
      # -*- Entry points: -*-

      [z3c.autoinclude.plugin]
      target = plone
      """,
      extras_require = {
          'test': [
              'plone.app.testing',
          ]
      },
      )
